%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Jyvaskylan yliopiston Fysiikan laitoksen LuK-tutkielma (jyflluk.cls)
% Dokumenttiluokka
% Versio 1.0 (4/3/2015)
% 
% Saantitapa:
% https://koppa.jyu.fi/kurssit/170784/materiaalikansio/jyflluk
%
% Alkuperäinen tekijä:
% Jussi Maunuksela (jussi.o.maunuksela at jyu.fi)
%
% Lisenssi:
% CC BY-NC-SA 3.0 (http://creativecommons.org/licenses/by-nc-sa/3.0/)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\ProvidesClass{jyflluk}[2015/03/45 versio 1.0 JYFL kandidaatintutkielman dokumenttiluokka]
\NeedsTeXFormat{LaTeX2e}

% ================================================================
% DOKUMENTTILUOKAN MÄÄRITELMÄT:
%
% Ladataan article -dokumenttiluokka seuraavilla lisämääreillä:
%
%   12pt      - Perusfontin pistekoko
%   a4paper - Paperikoko
%   
\LoadClass[12pt,a4paper,twoside]{article}

% ================================================================
%
% MAKROPAKETIT:
%

% ================================================================
% INPUTENC --- Määritellään käytettävä merkistö
%
\RequirePackage[utf8]{inputenc}

% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
% FONTENC --- Määritellään LaTeXin käyttämän kirjasimen merkkivalikoima 
%
\RequirePackage[T1]{fontenc}

% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
% LMODERN --- Ladataan Latin Modern kirjasimet
%
\RequirePackage{lmodern}

% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
% CAPTION --- Määritellään taulukoiden ja kuvioiden selitteiden muotoilu.
%
\RequirePackage[margin=10pt,labelfont=bf,labelsep=period]{caption}[2013/02/03]

% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
% BABEL --- Otetaan käyttöön suomenkieliset tavutussäännöt
%
\RequirePackage[english,finnish]{babel}

% Vaihdetaan lähdeluettelolle tulostuvaksi otsikoksi "Lähteet"
\addto\captionsfinnish{%
  \renewcommand{\refname}%
    {Lähteet}% Lähdeluettelon otsikon asettaminen
}
% Vaihtetaan kuvalle tulostuvaksi otsikoksi "Kuvio"
\addto\captionsfinnish{%
  \renewcommand{\figurename}%
    {Kuvio}% Kuvatekstin otsikon asettaminen
}

% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
% GEOMETRY --- Asetetaan marginaalien leveydet
%
\RequirePackage[a4paper,left=25mm,right=25mm,top=35mm,bottom=35mm,bindingoffset=10mm]{geometry}
\setlength{\headheight}{15pt}

% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
%  FANCYHDR --- Sivun ylä- ja alatunnisteiden määrittely
%
\RequirePackage{fancyhdr}
\fancypagestyle{firstpage}{%
  \fancyhf{}% clear all six fields
  \renewcommand{\headrulewidth}{0pt}
  \renewcommand{\footrulewidth}{0pt}
}
\fancypagestyle{followingpage}{%
  \fancyhf{}% clear all six fields
  \fancyhead[LE,RO]{\thepage}
  \renewcommand{\headrulewidth}{0pt}
  \renewcommand{\footrulewidth}{0pt}
}
\pagestyle{followingpage}
\AtBeginDocument{\thispagestyle{firstpage}}

% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
% PARSKIP --- Kappaleiden erottajan määrittely
%
\RequirePackage{parskip}

% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
%TITLESEC --- Otsikoiden asemoinnin ja muotoilun määrittely
%
\RequirePackage[noindentafter,nobottomtitles,toctitles]{titlesec}
\newcommand{\sectionbreak}{%
	\cleardoublepage%
	\vspace*{24pt}}
% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
% TOCBIBIND --- Lähteet -otsikon lisääminen sisällysluettelon perään.
%
\RequirePackage[nottoc]{tocbibind}

% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
% GRAPHICX --- Grafiikan lisääminen dokumenttiin. Oletuksen dokumentin tulostaminen pdf-muotoon
%
\RequirePackage{graphicx}

% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
% HYPERREF --- Hyperlinkkien ladonta tekstin sekaan. 
%
\RequirePackage{hyperref}

% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
% LASTPAGE --- Dokumentin viimeiseen sivuun viittaaminen. 
%
\RequirePackage{lastpage}

% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
% BOOKTABS --- Taulukoiden piirtäminen käyttäen viivoja, joiden ympärille jää sopivasti tilaa.
%
\RequirePackage{booktabs}

% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
% DATETIME --- Päiväyksen muotoilu
%
\RequirePackage{datetime}
\renewcommand{\dateseparator}{.}
\setdefaultdate{\dmyyyydate}

